# 人才标签管理 API 文档

本文档描述了与人才标签关系管理相关的 API 接口，包括获取人才标签和更新人才标签关系。

## API 接口: `/talent-get-tags/{talent_id}`

该 API 接口允许您根据人才 ID 获取关联的标签信息。

### 请求详情

- **请求方法**: GET
- **URL**: `/api/data_parse/talent-get-tags/{talent_id}`
- **Content-Type**: application/json

### 路径参数

| 参数名 | 类型 | 是否必需 | 描述 |
|-------|------|----------|------|
| `talent_id` | 整数 | 是 | 人才节点在 Neo4j 数据库中的 ID |

#### 请求示例
```
GET /api/data_parse/talent-get-tags/12345
```

### 响应格式

API 返回具有以下结构的 JSON 对象：

| 字段 | 类型 | 描述 |
|-----|------|------|
| `code` | 整数 | HTTP 状态码（200 表示成功，4xx/5xx 表示错误）|
| `success` | 布尔值 | 操作是否成功 |
| `message` | 字符串 | 结果描述或错误信息 |
| `data` | 数组 | 包含人才标签关系的对象数组 |

#### 成功响应示例
```json
{
  "code": 200,
  "success": true,
  "message": "获取人才标签成功",
  "data": [
    {
      "talent": 12345,
      "tag": "市场营销"
    },
    {
      "talent": 12345,
      "tag": "酒店管理"
    }
  ]
}
```

#### 错误响应示例
```json
{
  "code": 500,
  "success": false,
  "message": "获取人才标签失败: 人才节点ID 12345 不存在",
  "data": []
}
```

### 响应状态码

| 状态码 | 描述 |
|-------|------|
| 200 | 请求成功 |
| 500 | 服务器错误（处理错误或数据库连接失败）|

### 错误处理

如果发生错误，响应将包括：
- 非 200 状态码
- `success` 设置为 `false`
- 描述性错误信息
- 空的 `data` 数组


## API 接口: `/talent-update-tags`

该 API 接口允许您创建或更新人才与标签之间的关系。如果指定的标签不存在，系统会自动创建标签节点。

### 请求详情

- **请求方法**: POST
- **URL**: `/api/data_parse/talent-update-tags`
- **Content-Type**: application/json

### 请求参数

请求体应为 JSON 数组，包含多个对象，每个对象指定一个人才与标签的关系：

| 字段 | 类型 | 是否必需 | 描述 |
|-----|------|----------|------|
| `talent` | 整数 | 是 | 人才节点在 Neo4j 数据库中的 ID |
| `tag` | 字符串 | 是 | 标签名称 |

#### 请求体示例
```json
[
  {"talent": 12345, "tag": "市场营销"},
  {"talent": 12345, "tag": "酒店管理"},
  {"talent": 67890, "tag": "领导力"}
]
```

### 响应格式

API 返回具有以下结构的 JSON 对象：

| 字段 | 类型 | 描述 |
|-----|------|------|
| `code` | 整数 | HTTP 状态码（200 表示成功，206 表示部分成功，4xx/5xx 表示错误）|
| `success` | 布尔值 | 操作是否成功 |
| `message` | 字符串 | 结果描述或错误信息 |
| `data` | 对象 | 包含成功和失败信息的详细数据 |

#### 成功响应示例
```json
{
  "code": 200,
  "success": true,
  "message": "成功创建或更新了 3 个标签关系",
  "data": {
    "success_count": 3,
    "total_count": 3,
    "failed_items": []
  }
}
```

#### 部分成功响应示例
```json
{
  "code": 206,
  "success": true,
  "message": "部分成功: 创建或更新了 2/3 个标签关系",
  "data": {
    "success_count": 2,
    "total_count": 3,
    "failed_items": [
      {"talent": 67890, "tag": "领导力"}
    ]
  }
}
```

#### 错误响应示例
```json
{
  "code": 400,
  "success": false,
  "message": "参数格式错误，需要JSON数组",
  "data": null
}
```

### 响应状态码

| 状态码 | 描述 |
|-------|------|
| 200 | 请求完全成功 |
| 206 | 部分内容（部分更新成功，部分失败）|
| 400 | 错误请求（缺少或无效参数）|
| 404 | 未找到（指定的人才节点不存在）|
| 500 | 服务器错误（处理错误或数据库连接失败）|

### 错误处理

如果发生错误，响应将包括：
- 相应的状态码
- `success` 设置为 `false`（对于完全失败的情况）
- 描述性错误信息
- 失败项目的详细信息（对于部分成功的情况）

## 前端集成示例

### 获取人才标签

```javascript
// 使用 Axios 的 Vue.js 示例
import axios from 'axios';

export default {
  data() {
    return {
      talentId: null,
      talentTags: [],
      isLoading: false,
      error: null
    }
  },
  methods: {
    async fetchTalentTags(talentId) {
      this.isLoading = true;
      this.error = null;
      
      try {
        const response = await axios.get(`/api/data_parse/talent-get-tags/${talentId}`);
        
        if (response.data.success) {
          this.talentTags = response.data.data;
        } else {
          this.error = response.data.message;
        }
      } catch (error) {
        this.error = error.response?.data?.message || '获取标签失败，请稍后重试';
      } finally {
        this.isLoading = false;
      }
    }
  }
}
```

### 更新人才标签

```javascript
// 使用 Axios 的 Vue.js 示例
import axios from 'axios';

export default {
  data() {
    return {
      talentTagsData: [
        {talent: 12345, tag: "市场营销"},
        {talent: 12345, tag: "酒店管理"}
      ],
      isUpdating: false,
      updateResult: null,
      error: null
    }
  },
  methods: {
    async updateTalentTags() {
      this.isUpdating = true;
      this.error = null;
      this.updateResult = null;
      
      try {
        const response = await axios.post('/api/data_parse/talent-update-tags', this.talentTagsData);
        
        this.updateResult = {
          success: response.data.success,
          message: response.data.message,
          details: response.data.data
        };
      } catch (error) {
        this.error = error.response?.data?.message || '更新标签失败，请稍后重试';
      } finally {
        this.isUpdating = false;
      }
    }
  }
}
```

```html
<!-- Vue.js 模板示例：更新人才标签 -->
<template>
  <div class="talent-tags-update">
    <h2>更新人才标签</h2>
    
    <div class="tag-input-form">
      <div v-for="(item, index) in talentTagsData" :key="index" class="tag-input-row">
        <div class="form-group">
          <label>人才 ID:</label>
          <input type="number" v-model.number="item.talent" />
        </div>
        <div class="form-group">
          <label>标签名称:</label>
          <input type="text" v-model="item.tag" />
        </div>
        <button @click="removeTag(index)" class="remove-btn">删除</button>
      </div>
      
      <button @click="addTagRow" class="add-btn">添加标签</button>
      <button 
        @click="updateTalentTags" 
        :disabled="isUpdating || !isValidData"
        class="submit-btn"
      >
        {{ isUpdating ? '更新中...' : '提交更新' }}
      </button>
    </div>
    
    <div v-if="error" class="error-message">
      {{ error }}
    </div>
    
    <div v-if="updateResult" class="result-summary">
      <h3>更新结果</h3>
      <p :class="{'success': updateResult.success, 'partial': updateResult.success && updateResult.details?.failed_items?.length > 0}">
        {{ updateResult.message }}
      </p>
      
      <div v-if="updateResult.details?.failed_items?.length > 0" class="failed-items">
        <h4>失败项目：</h4>
        <ul>
          <li v-for="(item, index) in updateResult.details.failed_items" :key="index">
            人才 ID: {{ item.talent }}, 标签: {{ item.tag }}
          </li>
        </ul>
      </div>
    </div>
  </div>
</template>
```

## 使用场景示例

### 场景一：获取人才标签

1. 展示人才详情页面时，获取该人才的所有标签
2. 根据获取的标签展示标签云或标签列表
3. 让用户了解人才的专业领域和特长

### 场景二：批量更新人才标签

1. 人力资源部门根据人才评估结果为多个人才分配标签
2. 在人才管理系统中，为选定的人才添加或更新专业能力标签
3. 在知识图谱维护工具中，批量创建人才与标签的关联关系

### 场景三：人才分类管理

1. 先通过标签接口获取人才现有标签
2. 根据业务需求调整和更新人才标签
3. 利用更新后的标签体系进行人才筛选和分类

## 注意事项

- 更新操作使用 MERGE 语句，如果关系已存在则更新，不存在则创建
- 如果指定的标签不存在，系统会自动创建标签节点，无需单独创建
- 批量更新时，如果某些项目失败，其他项目仍会继续处理
- 当传入大量数据时，建议分批处理以避免请求超时 